==> asm_9.1.orig.tar.xz: asm-9.1/asm-tree/src/test/java/org/objectweb/asm/tree/JumpInsnNodeTest.java <==
// ASM: a very small and fast Java bytecode manipulation framework
// Copyright (c) 2000-2011 INRIA, France Telecom
// All rights reserved.
//
// Redistribution and use in source and binary forms, with or without
// modification, are permitted provided that the following conditions
// are met:
// 1. Redistributions of source code must retain the above copyright
//    notice, this list of conditions and the following disclaimer.
// 2. Redistributions in binary form must reproduce the above copyright
//    notice, this list of conditions and the following disclaimer in the
//    documentation and/or other materials provided with the distribution.
// 3. Neither the name of the copyright holders nor the names of its
//    contributors may be used to endorse or promote products derived from
//    this software without specific prior written permission.
//
// THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
// AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
// IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
// ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER OR CONTRIBUTORS BE
// LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
// CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
// SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
// INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
// CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
// ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF
// THE POSSIBILITY OF SUCH DAMAGE.
package org.objectweb.asm.tree;

import static org.junit.jupiter.api.Assertions.assertEquals;

import org.junit.jupiter.api.Test;
import org.objectweb.asm.Opcodes;
import org.objectweb.asm.test.AsmTest;

/**
 * Unit tests for {@link JumpInsnNode}.
 *
 * @author Eric Bruneton
 */
public class JumpInsnNodeTest extends AsmTest {

  @Test
  public void testConstructor() {
    LabelNode labelNode = new LabelNode();

    JumpInsnNode jumpInsnNode = new JumpInsnNode(Opcodes.GOTO, labelNode);

    assertEquals(Opcodes.GOTO, jumpInsnNode.getOpcode());
    assertEquals(AbstractInsnNode.JUMP_INSN, jumpInsnNode.getType());
    assertEquals(labelNode, jumpInsnNode.label);
  }

  @Test
  public void testSetOpcode() {
    JumpInsnNode jumpInsnNode = new JumpInsnNode(Opcodes.GOTO, new LabelNode());

    jumpInsnNode.setOpcode(Opcodes.IFEQ);

    assertEquals(Opcodes.IFEQ, jumpInsnNode.getOpcode());
  }
}

==> asm_9.7.orig.tar.xz: asm-9.7/asm-tree/src/test/java/org/objectweb/asm/tree/JumpInsnNodeTest.java <==
// ASM: a very small and fast Java bytecode manipulation framework
// Copyright (c) 2000-2011 INRIA, France Telecom
// All rights reserved.
//
// Redistribution and use in source and binary forms, with or without
// modification, are permitted provided that the following conditions
// are met:
// 1. Redistributions of source code must retain the above copyright
//    notice, this list of conditions and the following disclaimer.
// 2. Redistributions in binary form must reproduce the above copyright
//    notice, this list of conditions and the following disclaimer in the
//    documentation and/or other materials provided with the distribution.
// 3. Neither the name of the copyright holders nor the names of its
//    contributors may be used to endorse or promote products derived from
//    this software without specific prior written permission.
//
// THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
// AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
// IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
// ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER OR CONTRIBUTORS BE
// LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
// CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
// SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
// INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
// CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
// ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF
// THE POSSIBILITY OF SUCH DAMAGE.
package org.objectweb.asm.tree;

import static org.junit.jupiter.api.Assertions.assertEquals;

import org.junit.jupiter.api.Test;
import org.objectweb.asm.Opcodes;
import org.objectweb.asm.test.AsmTest;

/**
 * Unit tests for {@link JumpInsnNode}.
 *
 * @author Eric Bruneton
 */
class JumpInsnNodeTest extends AsmTest {

  @Test
  void testConstructor() {
    LabelNode labelNode = new LabelNode();

    JumpInsnNode jumpInsnNode = new JumpInsnNode(Opcodes.GOTO, labelNode);

    assertEquals(Opcodes.GOTO, jumpInsnNode.getOpcode());
    assertEquals(AbstractInsnNode.JUMP_INSN, jumpInsnNode.getType());
    assertEquals(labelNode, jumpInsnNode.label);
  }

  @Test
  void testSetOpcode() {
    JumpInsnNode jumpInsnNode = new JumpInsnNode(Opcodes.GOTO, new LabelNode());

    jumpInsnNode.setOpcode(Opcodes.IFEQ);

    assertEquals(Opcodes.IFEQ, jumpInsnNode.getOpcode());
  }
}
